#!/bin/sh
##
##	A clone of a famous game.
##
##	build.sh	-	The graphics and sound extractor.
##
##	(c) Copyright 1999 by Lutz Sammer
##
##	$Id: build.sh,v 1.6 1999/12/03 09:18:27 root Exp $
##

###
### Change the next, to meet your requirements:
###

# parameters
#
# -z / -I : COMPRESS = gzip --force --best / bzip2 --force
# -p path : CDROM = /cdrom / /mnt/cdrom ..
# -o DIR = /usr/share/games/ale-clone/warii
# -T path : BINPATH = /usr/lib/ale-clone/tools
# -C CONTRIB = /usr/lib/ale-clone/contrib

GZIP="gzip --force --best"
BZIP2="bzip2 --force"

CDROM="/cdrom"
[ -d "/mnt/cdrom" ] && CDROM="/mnt/cdrom"
DIR="/usr/share/games/ale-clone/WarII"

COMPRESS=$GZIP

BINPATH="/usr/lib/ale-clone/tools"
CONTRIB="/usr/lib/ale-clone/contrib"

while [ $# -gt 0 ]; do
	case "$1" in
		-p)	CDROM="$2"; shift ;;
		-o)	DIR="$2"; shift ;;

		-z)	COMPRESS="$GZIP" ;;
		-I)	COMPRESS="$BZIP2" ;;

		-T)	BINPATH="$2"; shift ;;
		-C)	CONTRIB="$2"; shift ;;

		*)
			echo 2>&1 "Unknown option: $1"
			exit 1
	esac
	shift
done

if [ -d "$CDROM/data/" ]; then
	DATADIR="$CDROM/data/"
else
	DATADIR="$CDROM/"
fi

###
###	Below this point, you should only search bugs. :-)
###

# Create the directory structure

[ -d $DIR ] || mkdir $DIR

[ -d $DIR/graphic ] || mkdir $DIR/graphic
[ -d $DIR/graphic/tileset ] || mkdir $DIR/graphic/tileset
[ -d $DIR/graphic/interface ] || mkdir $DIR/graphic/interface

[ -d $DIR/sound ] || mkdir $DIR/sound 

[ -d $DIR/campaigns ] || mkdir $DIR/campaigns
[ -d $DIR/campaigns/human ] || mkdir $DIR/campaigns/human
[ -d $DIR/campaigns/orc ] || mkdir $DIR/campaigns/orc
[ -d $DIR/campaigns/human-exp ] || mkdir $DIR/campaigns/human-exp
[ -d $DIR/campaigns/orc-exp ] || mkdir $DIR/campaigns/orc-exp
[ -d $DIR/text ] || mkdir $DIR/text

[ -d $DIR/puds ] || mkdir $DIR/puds 
[ -d $DIR/puds/internal ] || mkdir $DIR/puds/internal
[ -d $DIR/puds/demo ] || mkdir $DIR/puds/demo

###############################################################################
##	Extract
###############################################################################

$BINPATH/wartool "$DATADIR" "$DIR"

# own supplied files

cp $CONTRIB/cross.png $DIR/graphic
cp $CONTRIB/mana.png $DIR
cp $CONTRIB/health.png $DIR
cp $CONTRIB/ale-title.png $DIR

###############################################################################
##	MISC
###############################################################################

#
#	Compress the sounds
#
find $DIR/sound -type f -name "*.wav" -print -exec $COMPRESS {} \;

#
#	Compress the texts
#
find $DIR/text -type f -name "*.txt" -print -exec $COMPRESS {} \;

#
#	Copy original puds into data directory
#
echo "Copy puds and compressing"
[ -d $DATADIR/../puds ] && cp -r $DATADIR/../puds/ $DIR/puds
[ -f $DATADIR/../alamo.pud ] && cp -r $DATADIR/../*.pud $DIR/puds
chmod -R +w $DIR/puds
find $DIR/puds -type f -name "*.pud" -print -exec $COMPRESS {} \;

#
##	The default pud.
#
[ -f $DIR/puds/internal/internal12.pud.gz ] \
	&& ln -s puds/internal/internal12.pud.gz $DIR/default.pud.gz
[ -f $DIR/puds/internal/internal12.pud.bz2 ] \
	&& ln -s puds/internal/internal12.pud.bz2 $DIR/default.pud.bz2

#
# 	Some checks
#
[ -s $DIR/swamp.rgb ] || echo "This script isn't tested with the non-expansion CD!"
